# Issue Type

- Bug report
- Feature request

# Molecule and Ansible details

```
ansible --version
molecule --version
```

- Molecule installation method: One of source, pip
- Ansible installation method: One of source, pip, OS package

# Desired Behaviour

Please give some details of the feature being requested or what
should happen if providing a bug report.

# Actual Behaviour (Bug report only)

Please give some details of what is actually happening.
Include a [minimum complete verifiable example](http://stackoverflow.com/help/mcve) with
output of running `molecule --debug`.
